.. _installation:

Installation
============

Scippnexus requires Python 3.8 or above.

Conda
-----

Packages from `Anaconda Cloud <https://conda.anaconda.org/scipp>`_ are available for Linux, macOS, and Windows.

.. code-block:: sh

   conda install -c conda-forge -c scipp scippnexus

Pip
---

Scippnexus is available from `PyPI <https://pypi.org/>`_ via ``pip``:

.. code-block:: sh

   pip install scippnexus


See also
--------

See also the `scipp installation instructions <https://scipp.github.io/getting-started/installation.html>`_ on how to setup a conda environment and how to install additional dependencies such plotting libraries or Jupyter.
